#!/bin/bash
#
#   USAGE:  buildGeant4.sh [debug]

extras=${1}
if [ "${extras}" = "debug" ]
then
    qual=gcc45:debug
    qdir=gcc45-debug
else
    qual=gcc45
    qdir=gcc45
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
g4dir=${PRODUCTS}/geant4/v4_9_4_p01/${flvr}-${qdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${g4dir}
if [ ! -d ${g4dir} ]
then
   echo "ERROR: failed to create ${g4dir}"
   exit 1
fi

# declare and then setup geant4
echo "Declaring geant4 v4_9_4_p01 for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare geant4 v4_9_4_p01 -r geant4/v4_9_4_p01 -2 -m geant4.table -q ${qual}
   ups declare geant4 v4_9_4_p01 -r geant4/v4_9_4_p01 -2 -m geant4.table -q build-${qual}
else 
   ups declare geant4 v4_9_4_p01 -r geant4/v4_9_4_p01 -4 -m geant4.table -q ${qual}
   ups declare geant4 v4_9_4_p01 -r geant4/v4_9_4_p01 -4 -m geant4.table -q build-${qual}
fi

# have to create the G4INSTALL directory before setup
cd ${g4dir}
tar xzf ../source/geant4.9.4.p01.tar.gz

# this will complain because the lib directory does not yet exist
setup geant4 v4_9_4_p01  -q build-${qual}

gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ ! -d ${G4WORKDIR} ]
then
   echo "ERROR: cannot find geant4 directory ${G4WORKDIR}"
   exit 1
fi

if [ ! -d ${G4INSTALL} ]
then
   echo "ERROR: cannot find geant4 directory ${G4INSTALL,}"
   exit 1
fi

set -x 

cd ${G4INSTALL}/source
make clean
make
make includes

set +x 

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building geant4 v4_9_4_p01 ${flvr} -q ${qual}"
setup geant4 v4_9_4_p01 -q ${qual}
echo "G4LIB is ${G4LIB}"

exit 0
